---
permalink: /manual/storage
---

# Lagermanagement

Der KMUHelper besitzt ein integriertes Lagermanagement, leider können jedoch nicht mehrere Lager erfasst werden.

Bei jedem Produkt gibt es das Feld "Lagerbestand". Dieses wird bei folgenden Ereignissen aktualisiert:

-   Manuelle Änderung
-   Lieferung als "eingelagert" markieren
-   Bestellung als "versendet" markieren

## Zurück

[Zurück zum Handbuch](./)
